Skip to main content
https://badge.fury.io/py/keepass_http.png https://pypip.in/d/keepass_http/badge.png https://requires.io/github/bh/python-keepass-httpd/requirements.png?branch=master https://travis-ci.org/bh/python-keepass-httpd.png?branch=master https://coveralls.io/repos/bh/python-keepass-httpd/badge.png

Description

Installation

on Archlinux

Use Yaourt to install python-keepass-httpd. If it is installed you can install python-keepass-httpd with:

$ yaourt -S python-keepass-httpd-git

Yaourt will install the package and its dependencies.

on all other Unix/Linux systems

Use pip to install:

$ pip install 'keepass_http[GUI]' --use-mirrors

or without GUI support:

$ pip install keepass_http --use-mirrors

Usage

You can see the usage with:

$ python-keepass-httpd --help

The output should be look like this:

Usage:
  python-keepass-httpd run <database_path> [options]
  python-keepass-httpd (-h | --help)
  python-keepass-httpd --version

Options:
  --help                    Show this screen.
  -v --version              Show version.
  -d --daemon               Start as daemon
  -p --port PORT            Specify a port [default: 19455]
  -h --host HOST            Specify a host [default: 127.0.0.1]
  -l --loglevel LOGLEVEL    Loglevel to use [default: INFO]
  --gui                     Use QT (PySide) for a graphical interface

Starting the server

$ python-keepass-httpd run /home/kiwisauce/Dropbox/test.kdb
2014-03-07 13:28:04,534 [INFO] keepass_http_script: Server started on 127.0.0.1:19455

The server was started. Now we have to setup ChromeIPass.

Setting up ChromeIPass

Metadata

Release files for keepass_http 0.4.4

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distributions (sdists)

Source distribution for keepass_http 0.4.4
File Size Uploaded Provenance
keepass_http-0.4.4.zip 22.0 kB Without provenance Details
keepass_http-0.4.4.tar.gz 12.9 kB Without provenance Details
keepass_http-0.4.4.tar.bz2 11.7 kB Without provenance Details

Built distribution (wheel)

Table of built distributions (wheels) for keepass_http 0.4.4
File Interpreter ABI Platform
keepass_http-0.4.4-py2-none-any.whl Python 2 none any Details

Total release size: 66.4 kB

Release files / keepass_http-0.4.4.zip

Download URL keepass_http-0.4.4.zip
Size 22.0 kB
Tags Source
SHA-256 checksum
How to use checksums
09a3b3cf494c6466ca82531ceb92a560a3f475ed0ae9de87c6cb0d364fcf6e78
BLAKE2b-256 checksum
How to use checksums
ecb108dc8c2229b132cb0cc3eb552ac64ffde6c7139f46bc1eebb99cae627c20
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No

Release files / keepass_http-0.4.4.tar.gz

Download URL keepass_http-0.4.4.tar.gz
Size 12.9 kB
Tags Source
SHA-256 checksum
How to use checksums
67dd49cd167c2d625be14777b7e17b29ab1b60e2ec39c021567fb610ec899284
BLAKE2b-256 checksum
How to use checksums
1e92e05c9c04d297dd1a282b87ab4e5a8bd9d74f6089e77a25243c17f4074262
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No

Release files / keepass_http-0.4.4.tar.bz2

Download URL keepass_http-0.4.4.tar.bz2
Size 11.7 kB
Tags Source
SHA-256 checksum
How to use checksums
fc24b7150fd58a47bec98ab0eabd58439b5b5e54b4cafbd5817fd51962baf4f9
BLAKE2b-256 checksum
How to use checksums
853710d221c3f7a0c393668a8d30cd7a79bb310a61856a19b6c246f8f45017b9
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No

Release files / keepass_http-0.4.4-py2-none-any.whl

Download URL keepass_http-0.4.4-py2-none-any.whl
Size 19.7 kB
Tags Python 2
SHA-256 checksum
How to use checksums
a1cddef4c3d94dec1c4aef0b415d45f98e8f9c9bc5a2d052bedaa3cf4393d516
BLAKE2b-256 checksum
How to use checksums
61659db72226857a69d403a88ac3895b27f35583ba86d43162747a1bf85e459d
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No

Security for keepass_http 0.4.4

Provenance

Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.

No provenance found

None of the files in this release were uploaded with provenance metadata.

A note on package security

PyPI is a repository for distributing packages, not a service for auditing them. While third-party security researchers and our staff do their best to detect and remove malicious packages, PyPI cannot guarantee the quality, security or suitability of any given package.

To learn more about protecting yourself from malicious actors, visit our package security documentation.

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page